uniform sampler2D al_tex;
uniform bool      al_use_tex;
uniform vec2      lightPos;
uniform float     lightRadius;
uniform vec4      lightColor;

varying vec4      varyingColor;
varying vec2      varyingTexcoord;

void main()
{
    vec4 diffuseColor = vec4(1.0);

    if (al_use_tex)
    {
        // light's texture to draw (not currently used)
        diffuseColor = texture2D(al_tex, varyingTexcoord);
    }

    // discard all transparent fragments to avoid writing to the depth buffer.
    if (varyingColor.a * diffuseColor.a == 0.0)
    {
        discard;
    }

    // light position is in the center of the area being drawn
    vec2 lightPos = vec2(lightRadius, lightRadius);

    // distance of the fragment being drawn from the source of the light
    float lightDist = distance(varyingTexcoord, lightPos);

    // light brightness (1.0 = full bright)
    float brightness = clamp(1.0 - (lightDist*lightDist)/(lightRadius*lightRadius), 0.0, 1.0);
    brightness *= brightness;

    // Pre-multiply light color with intensity
    // "N dot L" term also goes here for normal mapping
    vec3 diffuse = (lightColor.rgb * lightColor.a) * 1.0;

    vec3 finalColor = diffuseColor.rgb * diffuse * brightness;
    gl_FragColor = varyingColor * vec4(finalColor, diffuseColor.a);
}
